# Task2

内容：RDD编程，熟悉算子，读写文件

第3章 Spark编程基础

[3.1 Spark入门：RDD编程](http://dblab.xmu.edu.cn/blog/1700-2/)

[3.2 Spark入门：键值对RDD](http://dblab.xmu.edu.cn/blog/1706-2/)

[3.3 Spark入门：共享变量](http://dblab.xmu.edu.cn/blog/1707-2/)（提升-分布式必备）

3.4 数据读写

[3.4.1 Spark入门：文件数据读写](http://dblab.xmu.edu.cn/blog/1708-2/)

问题扩展：请用RDD实现一个PAT排名器，题目要求

[参考](https://pintia.cn/problem-sets/16/problems/677)